'use strict';

module.exports = {
  "rules": {
    "arrow-parens": ["error", "always"],
    "arrow-spacing": ["error", { "before": true, "after": true }],
    "brace-style": ["error", "1tbs", { "allowSingleLine": true }],
    "camelcase": ["warn", { "properties": "never" }],
    "comma-dangle": "error",
    "comma-style": ["error", "last"],
    "complexity": ["warn", 11],
    "consistent-this": ["error", "self"],
    "constructor-super": "error",
    "curly": ["error", "multi-line"],
    "default-case": "error",
    "dot-location": ["error", "property"],
    "dot-notation": ["error", { "allowKeywords": true }],
    "eqeqeq": ["error", "allow-null"],
    // https://github.com/eslint/eslint/issues/6195
    // "generator-star-spacing": ["error", "after"],
    "guard-for-in": "error",
    "indent": ["error", 2],
    "keyword-spacing": "error",
    "max-depth": ["warn", 6],
    "max-nested-callbacks": ["warn", 6],
    "max-params": ["warn", 5],
    "no-bitwise": "error",
    "no-case-declarations": "error",
    "no-class-assign": "error",
    "no-cond-assign": "error",
    "no-const-assign": "error",
    "no-constant-condition": "error",
    "no-control-regex": "error",
    "no-debugger": "error",
    "no-delete-var": "error",
    "no-dupe-args": "error",
    "no-dupe-class-members": "error",
    "no-dupe-keys": "error",
    "no-duplicate-case": "error",
    "no-else-return": "error",
    "no-empty": "error",
    "no-empty-character-class": "error",
    "no-empty-pattern": "error",
    "no-ex-assign": "error",
    "no-extra-boolean-cast": "error",
    "no-extra-parens": "error",
    "no-extra-semi": "error",
    "no-fallthrough": "error",
    "no-floating-decimal": "error",
    "no-func-assign": "error",
    "no-inline-comments": "off",
    "no-inner-declarations": "error",
    "no-invalid-regexp": "error",
    "no-irregular-whitespace": "error",
    "no-lonely-if": "error",
    "no-mixed-spaces-and-tabs": "error",
    "no-multiple-empty-lines": ["error", { "max": 2 }],
    "no-negated-in-lhs": "error",
    "no-nested-ternary": "error",
    "no-new-require": "error",
    "no-new-symbol": "error",
    "no-obj-calls": "error",
    "no-octal": "error",
    "no-redeclare": "error",
    "no-regex-spaces": "error",
    "no-restricted-syntax": ["error", "WithStatement"],
    "no-self-assign": "error",
    "no-self-compare": "error",
    "no-shadow": "off",
    "no-sparse-arrays": "error",
    "no-this-before-super": "error",
    "no-throw-literal": "error",
    "no-undef": "error",
    "no-underscore-dangle": "off",
    "no-unexpected-multiline": "error",
    "no-unneeded-ternary": "error",
    "no-unreachable": "error",
    "no-unused-labels": "error",
    "no-unused-vars": "error",
    "no-use-before-define": ["error", "nofunc"],
    "no-void": "error",
    "no-warning-comments": ["warn", {
      "terms": ["todo", "fixme", "xxx", "hack"],
      "location": "start"
    }],
    "one-var": ["error", "never"],
    "object-curly-spacing": ["error", "always"],
    "operator-linebreak": ["error", "before"],
    "padded-blocks": ["error", "never"],
    "prefer-const": "error",
    "quote-props": ["error", "as-needed"],
    "quotes": ["error", "single"],
    "radix": "error",
    "semi": ["error", "always"],
    "space-before-blocks": ["error", "always"],
    "space-before-function-paren": ["error", "never"],
    "space-in-parens": ["error", "never"],
    "spaced-comment": ["error", "always"],
    "strict": ["error", "safe"],
    "use-isnan": "error",
    // FIXME: https://github.com/eslint/eslint/issues/2108
    // In order to really get benefit from this rule we need to either fix the
    // above issue or stop adding a newline between our functions and their
    // corresponding JSDoc block
    "valid-jsdoc": ["warn", {
      "prefer": {
        "returns": "return"
      },
      "requireReturn": false,
      "requireParamDescription": false,
      "requireReturnDescription": false
    }],
    "valid-typeof": "error",
    "wrap-iife": ["error", "outside"],
    "wrap-regex": "error",
    "yield-star-spacing": ["error", { "before": false, "after": true }],
    "yoda": ["error", "never"]
  }
};
